.. _onchain_other_types:

Onchain types
-------------



Contract
------------------------------------

.. automodule:: pragma_sdk.onchain.types.contract
   :members:
   :undoc-members:
   :show-inheritance:

ExecutionConfig
------------------------------------

.. automodule:: pragma_sdk.onchain.types.execution_config
   :members:
   :undoc-members:
   :show-inheritance:

Other types
---------------------------------

.. automodule:: pragma_sdk.onchain.types.types
   :members:
   :undoc-members:
   :show-inheritance:
